Enum caesar_core::relay::RequestPacket
source · pub enum RequestPacket {
Join {
id: String,
},
Create {
id: Option<String>,
},
Leave,
}Expand description
Represents a packet sent by a client to the server.
The type field is used to determine the type of the packet. It can be one of the following
values:
Join: The client wants to join a room.Create: The client wants to create a new room.Leave: The client wants to leave the current room.
Variants
Join
The client wants to join a room.
The id field is the ID of the room that the client wants to join.
Create
The client wants to create a new room.
The id field is an optional field that specifies the ID of the new room. If it is None,
a random ID will be generated.
Leave
The client wants to leave the current room.